@@ -61,6 +61,18 @@ class TestJUnitXmlResult(unittest.TestCase):
 </testsuite>
 """, self.get_output())
 
+    def test_test_count(self):
+        class Passes(unittest.TestCase):
+            def test_me(self):
+                pass
+        self.result.startTestRun()
+        Passes("test_me").run(self.result)
+        Passes("test_me").run(self.result)
+        self.result.stopTestRun()
+        # When tests are run, the number of tests is counted.
+        output = self.get_output()
+        self.assertTrue('tests="2"' in output)
+
     def test_erroring_test(self):
         class Errors(unittest.TestCase):
             def test_me(self):
@@ -68,7 +80,7 @@ class TestJUnitXmlResult(unittest.TestCase):
         self.result.startTestRun()
         Errors("test_me").run(self.result)
         self.result.stopTestRun()
-        self.assertEqual("""<testsuite errors="1" failures="0" name="" tests="0" time="0.000">
+        self.assertEqual("""<testsuite errors="1" failures="0" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.Errors" name="test_me" time="0.000">
 <error type="exceptions.ZeroDivisionError">error</error>
 </testcase>
@@ -82,7 +94,7 @@ class TestJUnitXmlResult(unittest.TestCase):
         self.result.startTestRun()
         Fails("test_me").run(self.result)
         self.result.stopTestRun()
-        self.assertEqual("""<testsuite errors="0" failures="1" name="" tests="0" time="0.000">
+        self.assertEqual("""<testsuite errors="0" failures="1" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.Fails" name="test_me" time="0.000">
 <failure type="exceptions.AssertionError">failure</failure>
 </testcase>
@@ -96,7 +108,7 @@ class TestJUnitXmlResult(unittest.TestCase):
         self.result.startTestRun()
         Passes("test_me").run(self.result)
         self.result.stopTestRun()
-        self.assertEqual("""<testsuite errors="0" failures="0" name="" tests="0" time="0.000">
+        self.assertEqual("""<testsuite errors="0" failures="0" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.Passes" name="test_me" time="0.000" />
 </testsuite>
 """, self.get_output())
@@ -110,7 +122,7 @@ class TestJUnitXmlResult(unittest.TestCase):
         self.run_test_or_simulate(test, 'skipTest', self.result.addSkip, 'yo')
         self.result.stopTestRun()
         output = self.get_output()
-        expected = """<testsuite errors="0" failures="0" name="" tests="0" time="0.000">
+        expected = """<testsuite errors="0" failures="0" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.Skips" name="test_me" time="0.000">
 <skip>yo</skip>
 </testcase>
@@ -129,7 +141,7 @@ class TestJUnitXmlResult(unittest.TestCase):
         self.result.startTestRun()
         Succeeds("test_me").run(self.result)
         self.result.stopTestRun()
-        self.assertEqual("""<testsuite errors="0" failures="0" name="" tests="0" time="0.000">
+        self.assertEqual("""<testsuite errors="0" failures="0" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.Succeeds" name="test_me" time="0.000" />
 </testsuite>
 """, self.get_output())
@@ -146,13 +158,13 @@ class TestJUnitXmlResult(unittest.TestCase):
         ExpectedFail("test_me").run(self.result)
         self.result.stopTestRun()
         output = self.get_output()
-        expected = """<testsuite errors="0" failures="1" name="" tests="0" time="0.000">
+        expected = """<testsuite errors="0" failures="1" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.ExpectedFail" name="test_me" time="0.000">
 <failure type="unittest._ExpectedFailure">failure</failure>
 </testcase>
 </testsuite>
 """
-        expected_old = """<testsuite errors="0" failures="1" name="" tests="0" time="0.000">
+        expected_old = """<testsuite errors="0" failures="1" name="" tests="1" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.ExpectedFail" name="test_me" time="0.000">
 <failure type="exceptions.AssertionError">failure</failure>
 </testcase>
